==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/3f/3fb8a1f57a93ddfe7e568888953bc6a8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php */
class __TwigTemplate_7f535cd02a7b762d16078ac743bc3566 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\LeadBundle\\Field\\Dispatcher;

use Doctrine\\ORM\\EntityManager;
use Mautic\\LeadBundle\\Entity\\LeadField;
use Mautic\\LeadBundle\\Event\\LeadFieldEvent;
use Mautic\\LeadBundle\\Exception\\NoListenerException;
use Mautic\\LeadBundle\\LeadEvents;
use Symfony\\Component\\EventDispatcher\\EventDispatcherInterface;

class FieldSaveDispatcher
{
    public function __construct(
        private EventDispatcherInterface \$dispatcher,
        private EntityManager \$entityManager
    ) {
    }

    /**
     * @throws NoListenerException
     */
    public function dispatchPreSaveEvent(LeadField \$entity, bool \$isNew): LeadFieldEvent
    {
        return \$this->dispatchEvent(LeadEvents::FIELD_PRE_SAVE, \$entity, \$isNew);
    }

    /**
     * @throws NoListenerException
     */
    public function dispatchPostSaveEvent(LeadField \$entity, bool \$isNew): LeadFieldEvent
    {
        return \$this->dispatchEvent(LeadEvents::FIELD_POST_SAVE, \$entity, \$isNew);
    }

    /**
     * @throws NoListenerException
     */
    public function dispatchEvent(string \$action, LeadField \$entity, bool \$isNew, ?LeadFieldEvent \$event = null): LeadFieldEvent
    {
        if (!\$this->dispatcher->hasListeners(\$action)) {
            throw new NoListenerException('There is no Listener for '.\$action.' event');
        }

        if (null === \$event) {
            \$event = new LeadFieldEvent(\$entity, \$isNew);
            \$event->setEntityManager(\$this->entityManager);
        }

        \$this->dispatcher->dispatch(\$event, \$action);

        return \$event;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/3f/3fb8a1f57a93ddfe7e568888953bc6a8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php */
class __TwigTemplate_7f535cd02a7b762d16078ac743bc3566 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\LeadBundle\\Field\\Dispatcher;

use Doctrine\\ORM\\EntityManager;
use Mautic\\LeadBundle\\Entity\\LeadField;
use Mautic\\LeadBundle\\Event\\LeadFieldEvent;
use Mautic\\LeadBundle\\Exception\\NoListenerException;
use Mautic\\LeadBundle\\LeadEvents;
use Symfony\\Component\\EventDispatcher\\EventDispatcherInterface;

class FieldSaveDispatcher
{
    public function __construct(
        private EventDispatcherInterface \$dispatcher,
        private EntityManager \$entityManager
    ) {
    }

    /**
     * @throws NoListenerException
     */
    public function dispatchPreSaveEvent(LeadField \$entity, bool \$isNew): LeadFieldEvent
    {
        return \$this->dispatchEvent(LeadEvents::FIELD_PRE_SAVE, \$entity, \$isNew);
    }

    /**
     * @throws NoListenerException
     */
    public function dispatchPostSaveEvent(LeadField \$entity, bool \$isNew): LeadFieldEvent
    {
        return \$this->dispatchEvent(LeadEvents::FIELD_POST_SAVE, \$entity, \$isNew);
    }

    /**
     * @throws NoListenerException
     */
    public function dispatchEvent(string \$action, LeadField \$entity, bool \$isNew, ?LeadFieldEvent \$event = null): LeadFieldEvent
    {
        if (!\$this->dispatcher->hasListeners(\$action)) {
            throw new NoListenerException('There is no Listener for '.\$action.' event');
        }

        if (null === \$event) {
            \$event = new LeadFieldEvent(\$entity, \$isNew);
            \$event->setEntityManager(\$this->entityManager);
        }

        \$this->dispatcher->dispatch(\$event, \$action);

        return \$event;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php", "/var/www/html/production-demo/app/bundles/LeadBundle/Field/Dispatcher/FieldSaveDispatcher.php");
    }
}
